#ifndef DOXYGEN_AUTODOC_HPP_FCL_BVH_BVH_MODEL_H
#define DOXYGEN_AUTODOC_HPP_FCL_BVH_BVH_MODEL_H

#include "/builddir/build/BUILD/agiros-loong-hpp-fcl-2.3.0/doc/python/doxygen.hh"

#include <hpp/fcl/BVH/BVH_model.h>

namespace doxygen {

template <typename BV>
struct class_doc_impl< hpp::fcl::BVHModel <BV > >
{
static inline const char* run ()
{
  return "A class describing the bounding hierarchy of a mesh model or a point cloud model (which is viewed as a degraded version of mesh) \n"
"\n"
"\n"
"Templateparam\n"
"  - BV one of the bounding volume class in Bounding volumes. ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "bv_splitter") == 0)
    return "Split rule to split one BV node into two children. ";
  if (strcmp(attrib, "bv_fitter") == 0)
    return "Fitting rule to fit a BV node to a set of geometry primitives. ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <typename BV>
struct constructor_0_impl< hpp::fcl::BVHModel <BV > >
{
static inline const char* doc ()
{
  return "Default constructor to build an empty BVH. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

template <typename BV>
struct constructor_1_impl< hpp::fcl::BVHModel <BV >, const hpp::fcl::BVHModel <BV >  & >
{
static inline const char* doc ()
{
  return "Copy constructor from another BVH. \n"
"\n"
"\n"
"Param\n"
"  - other hpp::fcl::BVHModel to copy. ";
}
static inline boost::python::detail::keywords<1+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("other"));
}
};

template <typename BV>
struct destructor_doc_impl < hpp::fcl::BVHModel <BV > >
{
static inline const char* run ()
{
  return "deconstruction, delete mesh data related. ";
}
};

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::BVHModel < BV > * (hpp::fcl::BVHModel <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::BVHModel < BV > * (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::clone))
    return "Clone *this into a new hpp::fcl::BVHModel. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::BVHModel < BV > * (hpp::fcl::BVHModel <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::BVHModel < BV > * (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::clone))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc (const hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*function_ptr) (unsigned int) const)
{
  if (function_ptr == static_cast<const hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*) (unsigned int) const>(&hpp::fcl::BVHModel <BV >::getBV))
    return "We provide getBV() and getNumBVs() because BVH may be compressed (in future), so we must provide some flexibility here. \n"
"\n"
"Access the bv giving the its index ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args (const hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*function_ptr) (unsigned int) const)
{
  if (function_ptr == static_cast<const hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*) (unsigned int) const>(&hpp::fcl::BVHModel <BV >::getBV))
    return (boost::python::arg("self"), boost::python::arg("i"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*function_ptr) (unsigned int))
{
  if (function_ptr == static_cast< hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*) (unsigned int)>(&hpp::fcl::BVHModel <BV >::getBV))
    return "Access the bv giving the its index. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args ( hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*function_ptr) (unsigned int))
{
  if (function_ptr == static_cast< hpp::fcl::BVNode < BV > & (hpp::fcl::BVHModel <BV >::*) (unsigned int)>(&hpp::fcl::BVHModel <BV >::getBV))
    return (boost::python::arg("self"), boost::python::arg("i"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc (unsigned int (hpp::fcl::BVHModel <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<unsigned int (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNumBVs))
    return "Get the number of bv in the BVH. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args (unsigned int (hpp::fcl::BVHModel <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<unsigned int (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNumBVs))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "Get the BV type: default is unknown. ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "Specialization of getNodeType() for hpp::fcl::BVHModel with different BV types. ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return "get the node type ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::BVHModel <BV >::*) () const>(&hpp::fcl::BVHModel <BV >::getNodeType))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc (int (hpp::fcl::BVHModel <BV >::*function_ptr) (const bool) const)
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModel <BV >::*) (const bool) const>(&hpp::fcl::BVHModel <BV >::memUsage))
    return "Check the number of memory used. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args (int (hpp::fcl::BVHModel <BV >::*function_ptr) (const bool) const)
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModel <BV >::*) (const bool) const>(&hpp::fcl::BVHModel <BV >::memUsage))
    return (boost::python::arg("self"), boost::python::arg("msg"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc (void (hpp::fcl::BVHModel <BV >::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::BVHModel <BV >::*) ()>(&hpp::fcl::BVHModel <BV >::makeParentRelative))
    return "This is a special acceleration: BVH_model default stores the BV's transform in world coordinate. However, we can also store each BV's transform related to its parent BV node. When traversing the BVH, this can save one matrix transformation. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::BVHModel <BV >::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::BVHModel <BV >::*) ()>(&hpp::fcl::BVHModel <BV >::makeParentRelative))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}
} // namespace doxygen
#include <hpp/fcl/BVH/BVH_model.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::BVHModelBase >
{
static inline const char* run ()
{
  return "A base class describing the bounding hierarchy of a mesh model or a point cloud model (which is viewed as a degraded version of mesh) ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "vertices") == 0)
    return "Geometry point data. ";
  if (strcmp(attrib, "tri_indices") == 0)
    return "Geometry triangle index data, will be NULL for point clouds. ";
  if (strcmp(attrib, "prev_vertices") == 0)
    return "Geometry point data in previous frame. ";
  if (strcmp(attrib, "num_tris") == 0)
    return "Number of triangles. ";
  if (strcmp(attrib, "num_vertices") == 0)
    return "Number of points. ";
  if (strcmp(attrib, "build_state") == 0)
    return "The state of BVH building process. ";
  if (strcmp(attrib, "convex") == 0)
    return "Convex<Triangle> representation of this object. ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_0_impl< hpp::fcl::BVHModelBase >
{
static inline const char* doc ()
{
  return "Constructing an empty BVH. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

template <>
struct constructor_1_impl< hpp::fcl::BVHModelBase, const hpp::fcl::BVHModelBase & >
{
static inline const char* doc ()
{
  return "copy from another BVH ";
}
static inline boost::python::detail::keywords<1+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("other"));
}
};

template <>
struct destructor_doc_impl < hpp::fcl::BVHModelBase >
{
static inline const char* run ()
{
  return "deconstruction, delete mesh data related. ";
}
};

inline const char* member_func_doc ( hpp::fcl::BVHModelType (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::BVHModelType (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::getModelType))
    return "Model type described by the instance. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::BVHModelType (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::BVHModelType (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::getModelType))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc ( hpp::fcl::OBJECT_TYPE (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::OBJECT_TYPE (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::getObjectType))
    return "Get the object type: it is a BVH. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::OBJECT_TYPE (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::OBJECT_TYPE (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::getObjectType))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (void (hpp::fcl::BVHModelBase::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::computeLocalAABB))
    return "Compute the hpp::fcl::AABB for the BVH, used for broad-phase collision. ";
  if (function_ptr == static_cast<void (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::makeParentRelative))
    return "This is a special acceleration: BVH_model default stores the BV's transform in world coordinate. However, we can also store each BV's transform related to its parent BV node. When traversing the BVH, this can save one matrix transformation. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::BVHModelBase::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::computeLocalAABB))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<void (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::makeParentRelative))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (unsigned int, unsigned int))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (unsigned int, unsigned int)>(&hpp::fcl::BVHModelBase::beginModel))
    return "Begin a new BVH model. ";
  return "";
}

inline boost::python::detail::keywords<3> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (unsigned int, unsigned int))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (unsigned int, unsigned int)>(&hpp::fcl::BVHModelBase::beginModel))
    return (boost::python::arg("self"), boost::python::arg("num_tris"), boost::python::arg("num_vertices"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Vec3f &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::addVertex))
    return "Add one point in the new BVH model. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::replaceVertex))
    return "Replace one point in the old BVH model. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::updateVertex))
    return "Update one point in the old BVH model. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Vec3f &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::addVertex))
    return (boost::python::arg("self"), boost::python::arg("p"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::replaceVertex))
    return (boost::python::arg("self"), boost::python::arg("p"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::updateVertex))
    return (boost::python::arg("self"), boost::python::arg("p"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Matrixx3f &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Matrixx3f &)>(&hpp::fcl::BVHModelBase::addVertices))
    return "Add points in the new BVH model. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Matrixx3f &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Matrixx3f &)>(&hpp::fcl::BVHModelBase::addVertices))
    return (boost::python::arg("self"), boost::python::arg("points"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Matrixx3i &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Matrixx3i &)>(&hpp::fcl::BVHModelBase::addTriangles))
    return "Add triangles in the new BVH model. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Matrixx3i &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Matrixx3i &)>(&hpp::fcl::BVHModelBase::addTriangles))
    return (boost::python::arg("self"), boost::python::arg("triangles"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::addTriangle))
    return "Add one triangle in the new BVH model. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::replaceTriangle))
    return "Replace one triangle in the old BVH model. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::updateTriangle))
    return "Update one triangle in the old BVH model. ";
  return "";
}

inline boost::python::detail::keywords<4> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::addTriangle))
    return (boost::python::arg("self"), boost::python::arg("p1"), boost::python::arg("p2"), boost::python::arg("p3"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::replaceTriangle))
    return (boost::python::arg("self"), boost::python::arg("p1"), boost::python::arg("p2"), boost::python::arg("p3"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::BVHModelBase::updateTriangle))
    return (boost::python::arg("self"), boost::python::arg("p1"), boost::python::arg("p2"), boost::python::arg("p3"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"), boost::python::arg("arg2"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const std::vector< hpp::fcl::Vec3f > &, const std::vector< hpp::fcl::Triangle > &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &, const std::vector< hpp::fcl::Triangle > &)>(&hpp::fcl::BVHModelBase::addSubModel))
    return "Add a set of triangles in the new BVH model. ";
  return "";
}

inline boost::python::detail::keywords<3> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const std::vector< hpp::fcl::Vec3f > &, const std::vector< hpp::fcl::Triangle > &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &, const std::vector< hpp::fcl::Triangle > &)>(&hpp::fcl::BVHModelBase::addSubModel))
    return (boost::python::arg("self"), boost::python::arg("ps"), boost::python::arg("ts"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const std::vector< hpp::fcl::Vec3f > &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &)>(&hpp::fcl::BVHModelBase::addSubModel))
    return "Add a set of points in the new BVH model. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &)>(&hpp::fcl::BVHModelBase::replaceSubModel))
    return "Replace a set of points in the old BVH model. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &)>(&hpp::fcl::BVHModelBase::updateSubModel))
    return "Update a set of points in the old BVH model. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const std::vector< hpp::fcl::Vec3f > &))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &)>(&hpp::fcl::BVHModelBase::addSubModel))
    return (boost::python::arg("self"), boost::python::arg("ps"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &)>(&hpp::fcl::BVHModelBase::replaceSubModel))
    return (boost::python::arg("self"), boost::python::arg("ps"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const std::vector< hpp::fcl::Vec3f > &)>(&hpp::fcl::BVHModelBase::updateSubModel))
    return (boost::python::arg("self"), boost::python::arg("ps"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) ())
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::endModel))
    return "End BVH model construction, will build the bounding volume hierarchy. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::beginReplaceModel))
    return "Replace the geometry information of current frame (i.e. should have the same mesh topology with the previous frame) ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::beginUpdateModel))
    return "Replace the geometry information of current frame (i.e. should have the same mesh topology with the previous frame). The current frame will be saved as the previous frame in prev_vertices. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) ())
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::endModel))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::beginReplaceModel))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) ()>(&hpp::fcl::BVHModelBase::beginUpdateModel))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (bool, bool))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (bool, bool)>(&hpp::fcl::BVHModelBase::endReplaceModel))
    return "End BVH model replacement, will also refit or rebuild the bounding volume hierarchy. ";
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (bool, bool)>(&hpp::fcl::BVHModelBase::endUpdateModel))
    return "End BVH model update, will also refit or rebuild the bounding volume hierarchy. ";
  return "";
}

inline boost::python::detail::keywords<3> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (bool, bool))
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (bool, bool)>(&hpp::fcl::BVHModelBase::endReplaceModel))
    return (boost::python::arg("self"), boost::python::arg("refit"), boost::python::arg("bottomup"));
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (bool, bool)>(&hpp::fcl::BVHModelBase::endUpdateModel))
    return (boost::python::arg("self"), boost::python::arg("refit"), boost::python::arg("bottomup"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"));
}

inline const char* member_func_doc (void (hpp::fcl::BVHModelBase::*function_ptr) (bool))
{
  if (function_ptr == static_cast<void (hpp::fcl::BVHModelBase::*) (bool)>(&hpp::fcl::BVHModelBase::buildConvexRepresentation))
    return "Build this hpp::fcl::Convex representation of this model. The result is stored in attribute convex. \n"
"\n"
"Note: this only takes the points of this model. It does not check that the object is convex. It does not compute a convex hull. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::BVHModelBase::*function_ptr) (bool))
{
  if (function_ptr == static_cast<void (hpp::fcl::BVHModelBase::*) (bool)>(&hpp::fcl::BVHModelBase::buildConvexRepresentation))
    return (boost::python::arg("self"), boost::python::arg("share_memory"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::BVHModelBase::*function_ptr) (bool, const char *))
{
  if (function_ptr == static_cast<bool (hpp::fcl::BVHModelBase::*) (bool, const char *)>(&hpp::fcl::BVHModelBase::buildConvexHull))
    return "Build a convex hull and store it in attribute convex. \n"
"\n"
"\n"
"Param\n"
"  - keepTriangle whether the convex should be triangulated. \n"
"  - qhullCommand see ConvexBase::convexHull. \n"
"\n"
"Return: true if this object is convex, hence the convex hull represents the same object. \n"
"\n"
"See: ConvexBase::convexHull \n"
"\n"
"Warning: At the moment, the return value only checks whether there are as many points in the convex hull as in the original object. This is neither necessary (duplicated vertices get merged) nor sufficient (think of a U with 4 vertices and 3 edges). ";
  return "";
}

inline boost::python::detail::keywords<3> member_func_args (bool (hpp::fcl::BVHModelBase::*function_ptr) (bool, const char *))
{
  if (function_ptr == static_cast<bool (hpp::fcl::BVHModelBase::*) (bool, const char *)>(&hpp::fcl::BVHModelBase::buildConvexHull))
    return (boost::python::arg("self"), boost::python::arg("keepTriangle"), boost::python::arg("qhullCommand"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"));
}

inline const char* member_func_doc (int (hpp::fcl::BVHModelBase::*function_ptr) (const bool) const)
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const bool) const>(&hpp::fcl::BVHModelBase::memUsage))
    return "";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (int (hpp::fcl::BVHModelBase::*function_ptr) (const bool) const)
{
  if (function_ptr == static_cast<int (hpp::fcl::BVHModelBase::*) (const bool) const>(&hpp::fcl::BVHModelBase::memUsage))
    return (boost::python::arg("self"), boost::python::arg("msg"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc ( hpp::fcl::Vec3f (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::Vec3f (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::computeCOM))
    return "compute center of mass ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::Vec3f (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::Vec3f (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::computeCOM))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc ( hpp::fcl::FCL_REAL (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::computeVolume))
    return "compute the volume ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::FCL_REAL (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::computeVolume))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc ( hpp::fcl::Matrix3f (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::Matrix3f (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::computeMomentofInertia))
    return "compute the inertia matrix, related to the origin ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::Matrix3f (hpp::fcl::BVHModelBase::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::Matrix3f (hpp::fcl::BVHModelBase::*) () const>(&hpp::fcl::BVHModelBase::computeMomentofInertia))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}
} // namespace doxygen

#endif // DOXYGEN_AUTODOC_HPP_FCL_BVH_BVH_MODEL_H

