#ifndef DOXYGEN_AUTODOC_HPP_FCL_BROADPHASE_BROADPHASE_CALLBACKS_H
#define DOXYGEN_AUTODOC_HPP_FCL_BROADPHASE_BROADPHASE_CALLBACKS_H

#include "/builddir/build/BUILD/agiros-loong-hpp-fcl-2.3.0/doc/python/doxygen.hh"

#include <hpp/fcl/broadphase/broadphase_callbacks.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::CollisionCallBackBase >
{
static inline const char* run ()
{
  return "Base callback class for collision queries. This class can be supersed by child classes to provide desired behaviors according to the application (e.g, only listing the potential CollisionObjects in collision). ";
}
static inline const char* attribute (const char* attrib)
{
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

inline const char* member_func_doc (void (hpp::fcl::CollisionCallBackBase::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionCallBackBase::*) ()>(&hpp::fcl::CollisionCallBackBase::init))
    return "Initialization of the callback before running the collision broadphase manager. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::CollisionCallBackBase::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionCallBackBase::*) ()>(&hpp::fcl::CollisionCallBackBase::init))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (bool (hpp::fcl::CollisionCallBackBase::*function_ptr) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *))
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *)>(&hpp::fcl::CollisionCallBackBase::collide))
    return "Collision evaluation between two objects in collision. This callback will cause the broadphase evaluation to stop if it returns true. \n"
"\n"
"\n"
"Param\n"
"  - o1 Collision object #1. \n"
"  - o2 Collision object #2. ";
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *)>(&hpp::fcl::CollisionCallBackBase::operator()))
    return "Functor call associated to the collide operation. ";
  return "";
}

inline boost::python::detail::keywords<3> member_func_args (bool (hpp::fcl::CollisionCallBackBase::*function_ptr) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *))
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *)>(&hpp::fcl::CollisionCallBackBase::collide))
    return (boost::python::arg("self"), boost::python::arg("o1"), boost::python::arg("o2"));
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *)>(&hpp::fcl::CollisionCallBackBase::operator()))
    return (boost::python::arg("self"), boost::python::arg("o1"), boost::python::arg("o2"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"));
}
} // namespace doxygen
#include <hpp/fcl/broadphase/broadphase_callbacks.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::DistanceCallBackBase >
{
static inline const char* run ()
{
  return "Base callback class for distance queries. This class can be supersed by child classes to provide desired behaviors according to the application (e.g, only listing the potential CollisionObjects in collision). ";
}
static inline const char* attribute (const char* attrib)
{
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

inline const char* member_func_doc (void (hpp::fcl::DistanceCallBackBase::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceCallBackBase::*) ()>(&hpp::fcl::DistanceCallBackBase::init))
    return "Initialization of the callback before running the collision broadphase manager. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::DistanceCallBackBase::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceCallBackBase::*) ()>(&hpp::fcl::DistanceCallBackBase::init))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (bool (hpp::fcl::DistanceCallBackBase::*function_ptr) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *,  hpp::fcl::FCL_REAL &))
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *,  hpp::fcl::FCL_REAL &)>(&hpp::fcl::DistanceCallBackBase::distance))
    return "Distance evaluation between two objects in collision. This callback will cause the broadphase evaluation to stop if it returns true. \n"
"\n"
"\n"
"Param\n"
"  - o1 Collision object #1. \n"
"  - o2 Collision object #2. \n"
"  - dist Distance between the two collision geometries. ";
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *,  hpp::fcl::FCL_REAL &)>(&hpp::fcl::DistanceCallBackBase::operator()))
    return "Functor call associated to the distance operation. ";
  return "";
}

inline boost::python::detail::keywords<4> member_func_args (bool (hpp::fcl::DistanceCallBackBase::*function_ptr) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *,  hpp::fcl::FCL_REAL &))
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *,  hpp::fcl::FCL_REAL &)>(&hpp::fcl::DistanceCallBackBase::distance))
    return (boost::python::arg("self"), boost::python::arg("o1"), boost::python::arg("o2"), boost::python::arg("dist"));
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceCallBackBase::*) ( hpp::fcl::CollisionObject *,  hpp::fcl::CollisionObject *,  hpp::fcl::FCL_REAL &)>(&hpp::fcl::DistanceCallBackBase::operator()))
    return (boost::python::arg("self"), boost::python::arg("o1"), boost::python::arg("o2"), boost::python::arg("dist"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"), boost::python::arg("arg2"));
}
} // namespace doxygen

#endif // DOXYGEN_AUTODOC_HPP_FCL_BROADPHASE_BROADPHASE_CALLBACKS_H

