#ifndef DOXYGEN_AUTODOC_HPP_FCL_COLLISION_DATA_H
#define DOXYGEN_AUTODOC_HPP_FCL_COLLISION_DATA_H

#include "/builddir/build/BUILD/agiros-loong-hpp-fcl-2.3.0/doc/python/doxygen.hh"

#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::CollisionRequest >
{
static inline const char* run ()
{
  return "request to the collision algorithm ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "num_max_contacts") == 0)
    return "The maximum number of contacts will return. ";
  if (strcmp(attrib, "enable_contact") == 0)
    return "whether the contact information (normal, penetration depth and contact position) will return ";
  if (strcmp(attrib, "enable_distance_lower_bound") == 0)
    return "Whether a lower bound on distance is returned when objects are disjoint. ";
  if (strcmp(attrib, "security_margin") == 0)
    return "Distance below which objects are considered in collision. See Collision. \n"
"\n"
"Note: If set to -inf, the objects tested for collision are considered as collision free and no test is actually performed by functions hpp::fcl::collide of class hpp::fcl::ComputeCollision. ";
  if (strcmp(attrib, "break_distance") == 0)
    return "Distance below which bounding volumes are broken down. See Collision. ";
  if (strcmp(attrib, "distance_upper_bound") == 0)
    return "Distance above which GJK solver makes an early stopping. GJK stops searching for the closest points when it proves that the distance between two geometries is above this threshold. \n"
"\n"
"Remark: Consequently, the closest points might be incorrect, but allows to save computational resources. ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_2_impl< hpp::fcl::CollisionRequest, const hpp::fcl::CollisionRequestFlag, size_t >
{
static inline const char* doc ()
{
  return "Constructor from a flag and a maximal number of contacts. \n"
"\n"
"\n"
"Param\n"
"  - flag Collision request flag \n"
"  - num_max_contacts Maximal number of allowed contacts ";
}
static inline boost::python::detail::keywords<2+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("flag"), boost::python::arg("num_max_contacts_"));
}
};

template <>
struct constructor_0_impl< hpp::fcl::CollisionRequest >
{
static inline const char* doc ()
{
  return "Default constructor. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

inline const char* member_func_doc (bool (hpp::fcl::CollisionRequest::*function_ptr) (const hpp::fcl::CollisionResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionRequest::*) (const hpp::fcl::CollisionResult &) const>(&hpp::fcl::CollisionRequest::isSatisfied))
    return "";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::CollisionRequest::*function_ptr) (const hpp::fcl::CollisionResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionRequest::*) (const hpp::fcl::CollisionResult &) const>(&hpp::fcl::CollisionRequest::isSatisfied))
    return (boost::python::arg("self"), boost::python::arg("result"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::CollisionRequest::*function_ptr) (const hpp::fcl::CollisionRequest &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionRequest::*) (const hpp::fcl::CollisionRequest &) const>(&hpp::fcl::CollisionRequest::operator==))
    return "whether two hpp::fcl::CollisionRequest are the same or not ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::CollisionRequest::*function_ptr) (const hpp::fcl::CollisionRequest &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionRequest::*) (const hpp::fcl::CollisionRequest &) const>(&hpp::fcl::CollisionRequest::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}
} // namespace doxygen
#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::CollisionResult >
{
static inline const char* run ()
{
  return "collision result ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "distance_lower_bound") == 0)
    return "Lower bound on distance between objects if they are disjoint. See Collision Note: computed only on request (or if it does not add any computational overhead). ";
  if (strcmp(attrib, "nearest_points") == 0)
    return "nearest points available only when distance_lower_bound is inferior to CollisionRequest::break_distance. ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_0_impl< hpp::fcl::CollisionResult >
{
static inline const char* doc ()
{
  return "";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

inline const char* member_func_doc (void (hpp::fcl::CollisionResult::*function_ptr) (const hpp::fcl::FCL_REAL &))
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (const hpp::fcl::FCL_REAL &)>(&hpp::fcl::CollisionResult::updateDistanceLowerBound))
    return "Update the lower bound only if the distance is inferior. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::CollisionResult::*function_ptr) (const hpp::fcl::FCL_REAL &))
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (const hpp::fcl::FCL_REAL &)>(&hpp::fcl::CollisionResult::updateDistanceLowerBound))
    return (boost::python::arg("self"), boost::python::arg("distance_lower_bound_"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (void (hpp::fcl::CollisionResult::*function_ptr) (const hpp::fcl::Contact &))
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (const hpp::fcl::Contact &)>(&hpp::fcl::CollisionResult::addContact))
    return "add one contact into result structure ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::CollisionResult::*function_ptr) (const hpp::fcl::Contact &))
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (const hpp::fcl::Contact &)>(&hpp::fcl::CollisionResult::addContact))
    return (boost::python::arg("self"), boost::python::arg("c"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::CollisionResult::*function_ptr) (const hpp::fcl::CollisionResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionResult::*) (const hpp::fcl::CollisionResult &) const>(&hpp::fcl::CollisionResult::operator==))
    return "whether two hpp::fcl::CollisionResult are the same or not ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::CollisionResult::*function_ptr) (const hpp::fcl::CollisionResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionResult::*) (const hpp::fcl::CollisionResult &) const>(&hpp::fcl::CollisionResult::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::CollisionResult::*function_ptr) () const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionResult::*) () const>(&hpp::fcl::CollisionResult::isCollision))
    return "return binary collision result ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (bool (hpp::fcl::CollisionResult::*function_ptr) () const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::CollisionResult::*) () const>(&hpp::fcl::CollisionResult::isCollision))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (size_t (hpp::fcl::CollisionResult::*function_ptr) () const)
{
  if (function_ptr == static_cast<size_t (hpp::fcl::CollisionResult::*) () const>(&hpp::fcl::CollisionResult::numContacts))
    return "number of contacts found ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (size_t (hpp::fcl::CollisionResult::*function_ptr) () const)
{
  if (function_ptr == static_cast<size_t (hpp::fcl::CollisionResult::*) () const>(&hpp::fcl::CollisionResult::numContacts))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (const hpp::fcl::Contact & (hpp::fcl::CollisionResult::*function_ptr) (size_t) const)
{
  if (function_ptr == static_cast<const hpp::fcl::Contact & (hpp::fcl::CollisionResult::*) (size_t) const>(&hpp::fcl::CollisionResult::getContact))
    return "get the i-th contact calculated ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (const hpp::fcl::Contact & (hpp::fcl::CollisionResult::*function_ptr) (size_t) const)
{
  if (function_ptr == static_cast<const hpp::fcl::Contact & (hpp::fcl::CollisionResult::*) (size_t) const>(&hpp::fcl::CollisionResult::getContact))
    return (boost::python::arg("self"), boost::python::arg("i"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (void (hpp::fcl::CollisionResult::*function_ptr) (size_t, const hpp::fcl::Contact &))
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (size_t, const hpp::fcl::Contact &)>(&hpp::fcl::CollisionResult::setContact))
    return "set the i-th contact calculated ";
  return "";
}

inline boost::python::detail::keywords<3> member_func_args (void (hpp::fcl::CollisionResult::*function_ptr) (size_t, const hpp::fcl::Contact &))
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (size_t, const hpp::fcl::Contact &)>(&hpp::fcl::CollisionResult::setContact))
    return (boost::python::arg("self"), boost::python::arg("i"), boost::python::arg("c"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"));
}

inline const char* member_func_doc (void (hpp::fcl::CollisionResult::*function_ptr) (std::vector< hpp::fcl::Contact > &) const)
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (std::vector< hpp::fcl::Contact > &) const>(&hpp::fcl::CollisionResult::getContacts))
    return "get all the contacts ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::CollisionResult::*function_ptr) (std::vector< hpp::fcl::Contact > &) const)
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) (std::vector< hpp::fcl::Contact > &) const>(&hpp::fcl::CollisionResult::getContacts))
    return (boost::python::arg("self"), boost::python::arg("contacts_"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (const std::vector< hpp::fcl::Contact > & (hpp::fcl::CollisionResult::*function_ptr) () const)
{
  if (function_ptr == static_cast<const std::vector< hpp::fcl::Contact > & (hpp::fcl::CollisionResult::*) () const>(&hpp::fcl::CollisionResult::getContacts))
    return "";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (const std::vector< hpp::fcl::Contact > & (hpp::fcl::CollisionResult::*function_ptr) () const)
{
  if (function_ptr == static_cast<const std::vector< hpp::fcl::Contact > & (hpp::fcl::CollisionResult::*) () const>(&hpp::fcl::CollisionResult::getContacts))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (void (hpp::fcl::CollisionResult::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) ()>(&hpp::fcl::CollisionResult::clear))
    return "clear the results obtained ";
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) ()>(&hpp::fcl::CollisionResult::swapObjects))
    return "reposition hpp::fcl::Contact objects when fcl inverts them during their construction. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::CollisionResult::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) ()>(&hpp::fcl::CollisionResult::clear))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<void (hpp::fcl::CollisionResult::*) ()>(&hpp::fcl::CollisionResult::swapObjects))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}
} // namespace doxygen
#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::Contact >
{
static inline const char* run ()
{
  return "hpp::fcl::Contact information returned by collision. ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "o1") == 0)
    return "collision object 1 ";
  if (strcmp(attrib, "o2") == 0)
    return "collision object 2 ";
  if (strcmp(attrib, "b1") == 0)
    return "contact primitive in object 1 if object 1 is mesh or point cloud, it is the triangle or point id if object 1 is geometry shape, it is NONE (-1), if object 1 is octree, it is the id of the cell ";
  if (strcmp(attrib, "b2") == 0)
    return "contact primitive in object 2 if object 2 is mesh or point cloud, it is the triangle or point id if object 2 is geometry shape, it is NONE (-1), if object 2 is octree, it is the id of the cell ";
  if (strcmp(attrib, "normal") == 0)
    return "contact normal, pointing from o1 to o2 ";
  if (strcmp(attrib, "pos") == 0)
    return "contact position, in world space ";
  if (strcmp(attrib, "penetration_depth") == 0)
    return "penetration depth ";
  if (strcmp(attrib, "NONE") == 0)
    return "invalid contact primitive information ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_0_impl< hpp::fcl::Contact >
{
static inline const char* doc ()
{
  return "Default constructor. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

template <>
struct constructor_4_impl< hpp::fcl::Contact, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int >
{
static inline const char* doc ()
{
  return "";
}
static inline boost::python::detail::keywords<4+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("o1_"), boost::python::arg("o2_"), boost::python::arg("b1_"), boost::python::arg("b2_"));
}
};

template <>
struct constructor_7_impl< hpp::fcl::Contact, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &,  hpp::fcl::FCL_REAL >
{
static inline const char* doc ()
{
  return "";
}
static inline boost::python::detail::keywords<7+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("o1_"), boost::python::arg("o2_"), boost::python::arg("b1_"), boost::python::arg("b2_"), boost::python::arg("pos_"), boost::python::arg("normal_"), boost::python::arg("depth_"));
}
};

inline const char* member_func_doc (bool (hpp::fcl::Contact::*function_ptr) (const hpp::fcl::Contact &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::Contact::*) (const hpp::fcl::Contact &) const>(&hpp::fcl::Contact::operator<))
    return "";
  if (function_ptr == static_cast<bool (hpp::fcl::Contact::*) (const hpp::fcl::Contact &) const>(&hpp::fcl::Contact::operator==))
    return "";
  if (function_ptr == static_cast<bool (hpp::fcl::Contact::*) (const hpp::fcl::Contact &) const>(&hpp::fcl::Contact::operator!=))
    return "";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::Contact::*function_ptr) (const hpp::fcl::Contact &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::Contact::*) (const hpp::fcl::Contact &) const>(&hpp::fcl::Contact::operator<))
    return (boost::python::arg("self"), boost::python::arg("other"));
  if (function_ptr == static_cast<bool (hpp::fcl::Contact::*) (const hpp::fcl::Contact &) const>(&hpp::fcl::Contact::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  if (function_ptr == static_cast<bool (hpp::fcl::Contact::*) (const hpp::fcl::Contact &) const>(&hpp::fcl::Contact::operator!=))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}
} // namespace doxygen
#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::DistanceRequest >
{
static inline const char* run ()
{
  return "request to the distance computation ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "enable_nearest_points") == 0)
    return "whether to return the nearest points ";
  if (strcmp(attrib, "rel_err") == 0)
    return "error threshold for approximate distance ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_3_impl< hpp::fcl::DistanceRequest, bool,  hpp::fcl::FCL_REAL,  hpp::fcl::FCL_REAL >
{
static inline const char* doc ()
{
  return "Param\n"
"  - enable_nearest_points_ enables the nearest points computation. \n"
"  - rel_err_ \n"
"  - abs_err_ ";
}
static inline boost::python::detail::keywords<3+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("enable_nearest_points_"), boost::python::arg("rel_err_"), boost::python::arg("abs_err_"));
}
};

inline const char* member_func_doc (bool (hpp::fcl::DistanceRequest::*function_ptr) (const hpp::fcl::DistanceResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceRequest::*) (const hpp::fcl::DistanceResult &) const>(&hpp::fcl::DistanceRequest::isSatisfied))
    return "";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::DistanceRequest::*function_ptr) (const hpp::fcl::DistanceResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceRequest::*) (const hpp::fcl::DistanceResult &) const>(&hpp::fcl::DistanceRequest::isSatisfied))
    return (boost::python::arg("self"), boost::python::arg("result"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::DistanceRequest::*function_ptr) (const hpp::fcl::DistanceRequest &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceRequest::*) (const hpp::fcl::DistanceRequest &) const>(&hpp::fcl::DistanceRequest::operator==))
    return "whether two hpp::fcl::DistanceRequest are the same or not ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::DistanceRequest::*function_ptr) (const hpp::fcl::DistanceRequest &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceRequest::*) (const hpp::fcl::DistanceRequest &) const>(&hpp::fcl::DistanceRequest::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}
} // namespace doxygen
#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::DistanceResult >
{
static inline const char* run ()
{
  return "distance result ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "min_distance") == 0)
    return "minimum distance between two objects. if two objects are in collision, min_distance <= 0. ";
  if (strcmp(attrib, "nearest_points") == 0)
    return "nearest points ";
  if (strcmp(attrib, "normal") == 0)
    return "In case both objects are in collision, store the normal. ";
  if (strcmp(attrib, "o1") == 0)
    return "collision object 1 ";
  if (strcmp(attrib, "o2") == 0)
    return "collision object 2 ";
  if (strcmp(attrib, "b1") == 0)
    return "information about the nearest point in object 1 if object 1 is mesh or point cloud, it is the triangle or point id if object 1 is geometry shape, it is NONE (-1), if object 1 is octree, it is the id of the cell ";
  if (strcmp(attrib, "b2") == 0)
    return "information about the nearest point in object 2 if object 2 is mesh or point cloud, it is the triangle or point id if object 2 is geometry shape, it is NONE (-1), if object 2 is octree, it is the id of the cell ";
  if (strcmp(attrib, "NONE") == 0)
    return "invalid contact primitive information ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_1_impl< hpp::fcl::DistanceResult,  hpp::fcl::FCL_REAL >
{
static inline const char* doc ()
{
  return "";
}
static inline boost::python::detail::keywords<1+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("min_distance_"));
}
};

inline const char* member_func_doc (void (hpp::fcl::DistanceResult::*function_ptr) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int))
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int)>(&hpp::fcl::DistanceResult::update))
    return "add distance information into the result ";
  return "";
}

inline boost::python::detail::keywords<6> member_func_args (void (hpp::fcl::DistanceResult::*function_ptr) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int))
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int)>(&hpp::fcl::DistanceResult::update))
    return (boost::python::arg("self"), boost::python::arg("distance"), boost::python::arg("o1_"), boost::python::arg("o2_"), boost::python::arg("b1_"), boost::python::arg("b2_"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"), boost::python::arg("arg2"), boost::python::arg("arg3"), boost::python::arg("arg4"));
}

inline const char* member_func_doc (void (hpp::fcl::DistanceResult::*function_ptr) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &))
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::DistanceResult::update))
    return "add distance information into the result ";
  return "";
}

inline boost::python::detail::keywords<9> member_func_args (void (hpp::fcl::DistanceResult::*function_ptr) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &))
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) ( hpp::fcl::FCL_REAL, const hpp::fcl::CollisionGeometry *, const hpp::fcl::CollisionGeometry *, int, int, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &, const hpp::fcl::Vec3f &)>(&hpp::fcl::DistanceResult::update))
    return (boost::python::arg("self"), boost::python::arg("distance"), boost::python::arg("o1_"), boost::python::arg("o2_"), boost::python::arg("b1_"), boost::python::arg("b2_"), boost::python::arg("p1"), boost::python::arg("p2"), boost::python::arg("normal_"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"), boost::python::arg("arg2"), boost::python::arg("arg3"), boost::python::arg("arg4"), boost::python::arg("arg5"), boost::python::arg("arg6"), boost::python::arg("arg7"));
}

inline const char* member_func_doc (void (hpp::fcl::DistanceResult::*function_ptr) (const hpp::fcl::DistanceResult &))
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) (const hpp::fcl::DistanceResult &)>(&hpp::fcl::DistanceResult::update))
    return "add distance information into the result ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::DistanceResult::*function_ptr) (const hpp::fcl::DistanceResult &))
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) (const hpp::fcl::DistanceResult &)>(&hpp::fcl::DistanceResult::update))
    return (boost::python::arg("self"), boost::python::arg("other_result"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (void (hpp::fcl::DistanceResult::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) ()>(&hpp::fcl::DistanceResult::clear))
    return "clear the result ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::DistanceResult::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::DistanceResult::*) ()>(&hpp::fcl::DistanceResult::clear))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (bool (hpp::fcl::DistanceResult::*function_ptr) (const hpp::fcl::DistanceResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceResult::*) (const hpp::fcl::DistanceResult &) const>(&hpp::fcl::DistanceResult::operator==))
    return "whether two hpp::fcl::DistanceResult are the same or not ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::DistanceResult::*function_ptr) (const hpp::fcl::DistanceResult &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::DistanceResult::*) (const hpp::fcl::DistanceResult &) const>(&hpp::fcl::DistanceResult::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}
} // namespace doxygen
#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::QueryRequest >
{
static inline const char* run ()
{
  return "base class for all query requests ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "enable_cached_gjk_guess") == 0)
    return "whether enable gjk initial guess @Deprecated Use gjk_initial_guess instead ";
  if (strcmp(attrib, "gjk_variant") == 0)
    return "whether to enable the Nesterov accleration of GJK ";
  if (strcmp(attrib, "gjk_convergence_criterion") == 0)
    return "convergence criterion used to stop GJK ";
  if (strcmp(attrib, "gjk_convergence_criterion_type") == 0)
    return "convergence criterion used to stop GJK ";
  if (strcmp(attrib, "gjk_tolerance") == 0)
    return "tolerance for the GJK algorithm ";
  if (strcmp(attrib, "gjk_max_iterations") == 0)
    return "maximum iteration for the GJK algorithm ";
  if (strcmp(attrib, "cached_gjk_guess") == 0)
    return "the gjk initial guess set by user ";
  if (strcmp(attrib, "cached_support_func_guess") == 0)
    return "the support function initial guess set by user ";
  if (strcmp(attrib, "enable_timings") == 0)
    return "enable timings when performing collision/distance request ";
  if (strcmp(attrib, "collision_distance_threshold") == 0)
    return "threshold below which a collision is considered. ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_0_impl< hpp::fcl::QueryRequest >
{
static inline const char* doc ()
{
  return "Default constructor. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

template <>
struct constructor_1_impl< hpp::fcl::QueryRequest, const hpp::fcl::QueryRequest & >
{
static inline const char* doc ()
{
  return "Copy constructor. ";
}
static inline boost::python::detail::keywords<1+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("other"));
}
};

inline const char* member_func_doc ( hpp::fcl::QueryRequest & (hpp::fcl::QueryRequest::*function_ptr) (const hpp::fcl::QueryRequest &))
{
  if (function_ptr == static_cast< hpp::fcl::QueryRequest & (hpp::fcl::QueryRequest::*) (const hpp::fcl::QueryRequest &)>(&hpp::fcl::QueryRequest::operator=))
    return "Copy assignment operator. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args ( hpp::fcl::QueryRequest & (hpp::fcl::QueryRequest::*function_ptr) (const hpp::fcl::QueryRequest &))
{
  if (function_ptr == static_cast< hpp::fcl::QueryRequest & (hpp::fcl::QueryRequest::*) (const hpp::fcl::QueryRequest &)>(&hpp::fcl::QueryRequest::operator=))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (void (hpp::fcl::QueryRequest::*function_ptr) (const hpp::fcl::QueryResult &))
{
  if (function_ptr == static_cast<void (hpp::fcl::QueryRequest::*) (const hpp::fcl::QueryResult &)>(&hpp::fcl::QueryRequest::updateGuess))
    return "";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::QueryRequest::*function_ptr) (const hpp::fcl::QueryResult &))
{
  if (function_ptr == static_cast<void (hpp::fcl::QueryRequest::*) (const hpp::fcl::QueryResult &)>(&hpp::fcl::QueryRequest::updateGuess))
    return (boost::python::arg("self"), boost::python::arg("result"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::QueryRequest::*function_ptr) (const hpp::fcl::QueryRequest &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::QueryRequest::*) (const hpp::fcl::QueryRequest &) const>(&hpp::fcl::QueryRequest::operator==))
    return "whether two hpp::fcl::QueryRequest are the same or not ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::QueryRequest::*function_ptr) (const hpp::fcl::QueryRequest &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::QueryRequest::*) (const hpp::fcl::QueryRequest &) const>(&hpp::fcl::QueryRequest::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}
} // namespace doxygen
#include <hpp/fcl/collision_data.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::QueryResult >
{
static inline const char* run ()
{
  return "base class for all query results ";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "cached_gjk_guess") == 0)
    return "stores the last GJK ray when relevant. ";
  if (strcmp(attrib, "cached_support_func_guess") == 0)
    return "stores the last support function vertex index, when relevant. ";
  if (strcmp(attrib, "timings") == 0)
    return "timings for the given request ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_0_impl< hpp::fcl::QueryResult >
{
static inline const char* doc ()
{
  return "";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};
} // namespace doxygen

#endif // DOXYGEN_AUTODOC_HPP_FCL_COLLISION_DATA_H

