#ifndef DOXYGEN_AUTODOC_HPP_FCL_HFIELD_H
#define DOXYGEN_AUTODOC_HPP_FCL_HFIELD_H

#include "/builddir/build/BUILD/agiros-loong-hpp-fcl-2.3.0/doc/python/doxygen.hh"

#include <hpp/fcl/hfield.h>

namespace doxygen {

template <typename BV>
struct class_doc_impl< hpp::fcl::HeightField <BV > >
{
static inline const char* run ()
{
  return "Data structure depicting a height field given by the base grid dimensions and the elevation along the grid. \n"
"\n"
"\n"
"Templateparam\n"
"  - BV one of the bounding volume class in Bounding volumes.\n"
"\n"
"An height field is defined by its base dimensions along the X and Y axes and a set ofpoints defined by their altitude, regularly dispatched on the grid. The height field is centered at the origin and the corners of the geometry correspond to the following coordinates [± x_dim/2; ± y_dim/2]. ";
}
static inline const char* attribute (const char* attrib)
{
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <typename BV>
struct constructor_0_impl< hpp::fcl::HeightField <BV > >
{
static inline const char* doc ()
{
  return "Constructing an empty hpp::fcl::HeightField. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

template <typename BV>
struct constructor_4_impl< hpp::fcl::HeightField <BV >, const hpp::fcl::FCL_REAL, const hpp::fcl::FCL_REAL, const hpp::fcl::MatrixXf &, const hpp::fcl::FCL_REAL >
{
static inline const char* doc ()
{
  return "Constructing an hpp::fcl::HeightField from its base dimensions and the set of heights points. The granularity of the height field along X and Y direction is extraded from the Z grid. \n"
"\n"
"\n"
"Param\n"
"  - x_dim Dimension along the X axis \n"
"  - y_dim Dimension along the Y axis \n"
"  - heights Matrix containing the altitude of each point compositng the height field \n"
"  - min_height Minimal height of the height field ";
}
static inline boost::python::detail::keywords<4+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("x_dim"), boost::python::arg("y_dim"), boost::python::arg("heights"), boost::python::arg("min_height"));
}
};

template <typename BV>
struct constructor_1_impl< hpp::fcl::HeightField <BV >, const hpp::fcl::HeightField <BV >  & >
{
static inline const char* doc ()
{
  return "Copy contructor from another hpp::fcl::HeightField. \n"
"\n"
"\n"
"Param\n"
"  - other to copy. ";
}
static inline boost::python::detail::keywords<1+1> args ()
{
  return (boost::python::arg("self"), boost::python::arg("other"));
}
};

template <typename BV>
struct destructor_doc_impl < hpp::fcl::HeightField <BV > >
{
static inline const char* run ()
{
  return "deconstruction, delete mesh data related. ";
}
};

template <typename BV>
inline const char* member_func_doc (const hpp::fcl::VecXf & (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<const hpp::fcl::VecXf & (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getXGrid))
    return "Returns a const reference of the grid along the X direction. ";
  if (function_ptr == static_cast<const hpp::fcl::VecXf & (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getYGrid))
    return "Returns a const reference of the grid along the Y direction. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args (const hpp::fcl::VecXf & (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<const hpp::fcl::VecXf & (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getXGrid))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<const hpp::fcl::VecXf & (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getYGrid))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc (const hpp::fcl::MatrixXf & (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<const hpp::fcl::MatrixXf & (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getHeights))
    return "Returns a const reference of the heights. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args (const hpp::fcl::MatrixXf & (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<const hpp::fcl::MatrixXf & (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getHeights))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getXDim))
    return "Returns the dimension of the Height Field along the X direction. ";
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getYDim))
    return "Returns the dimension of the Height Field along the Y direction. ";
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getMinHeight))
    return "Returns the minimal height value of the Height Field. ";
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getMaxHeight))
    return "Returns the maximal height value of the Height Field. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getXDim))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getYDim))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getMinHeight))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getMaxHeight))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::HeightField < BV > * (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::HeightField < BV > * (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::clone))
    return "Clone *this into a new hpp::fcl::CollisionGeometry. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::HeightField < BV > * (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::HeightField < BV > * (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::clone))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc (void (hpp::fcl::HeightField <BV >::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::HeightField <BV >::*) ()>(&hpp::fcl::HeightField <BV >::computeLocalAABB))
    return "Compute the hpp::fcl::AABB for the hpp::fcl::HeightField, used for broad-phase collision. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args (void (hpp::fcl::HeightField <BV >::*function_ptr) ())
{
  if (function_ptr == static_cast<void (hpp::fcl::HeightField <BV >::*) ()>(&hpp::fcl::HeightField <BV >::computeLocalAABB))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc (void (hpp::fcl::HeightField <BV >::*function_ptr) (const hpp::fcl::MatrixXf &))
{
  if (function_ptr == static_cast<void (hpp::fcl::HeightField <BV >::*) (const hpp::fcl::MatrixXf &)>(&hpp::fcl::HeightField <BV >::updateHeights))
    return "Update Height Field height. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args (void (hpp::fcl::HeightField <BV >::*function_ptr) (const hpp::fcl::MatrixXf &))
{
  if (function_ptr == static_cast<void (hpp::fcl::HeightField <BV >::*) (const hpp::fcl::MatrixXf &)>(&hpp::fcl::HeightField <BV >::updateHeights))
    return (boost::python::arg("self"), boost::python::arg("new_heights"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc (const hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*function_ptr) (unsigned int) const)
{
  if (function_ptr == static_cast<const hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*) (unsigned int) const>(&hpp::fcl::HeightField <BV >::getBV))
    return "Access the bv giving the its index. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args (const hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*function_ptr) (unsigned int) const)
{
  if (function_ptr == static_cast<const hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*) (unsigned int) const>(&hpp::fcl::HeightField <BV >::getBV))
    return (boost::python::arg("self"), boost::python::arg("i"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*function_ptr) (unsigned int))
{
  if (function_ptr == static_cast< hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*) (unsigned int)>(&hpp::fcl::HeightField <BV >::getBV))
    return "Access the bv giving the its index. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args ( hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*function_ptr) (unsigned int))
{
  if (function_ptr == static_cast< hpp::fcl::HFNode < BV > & (hpp::fcl::HeightField <BV >::*) (unsigned int)>(&hpp::fcl::HeightField <BV >::getBV))
    return (boost::python::arg("self"), boost::python::arg("i"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "Get the BV type: default is unknown. ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "Specialization of getNodeType() for hpp::fcl::HeightField with different BV types. ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return "get the node type ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast< hpp::fcl::NODE_TYPE (hpp::fcl::HeightField <BV >::*) () const>(&hpp::fcl::HeightField <BV >::getNodeType))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}
} // namespace doxygen
#include <hpp/fcl/hfield.h>

namespace doxygen {

template <typename BV>
struct class_doc_impl< hpp::fcl::HFNode <BV > >
{
static inline const char* run ()
{
  return "";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "bv") == 0)
    return "bounding volume storing the geometry ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <typename BV>
struct destructor_doc_impl < hpp::fcl::HFNode <BV > >
{
static inline const char* run ()
{
  return "";
}
};

template <typename BV>
inline const char* member_func_doc (bool (hpp::fcl::HFNode <BV >::*function_ptr) (const hpp::fcl::HFNode <BV >  &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &) const>(&hpp::fcl::HFNode <BV >::operator==))
    return "Equality operator. ";
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &) const>(&hpp::fcl::HFNode <BV >::operator!=))
    return "Difference operator. ";
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &) const>(&hpp::fcl::HFNode <BV >::overlap))
    return "Check whether two hpp::fcl::BVNode collide. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::HFNode <BV >::*function_ptr) (const hpp::fcl::HFNode <BV >  &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &) const>(&hpp::fcl::HFNode <BV >::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &) const>(&hpp::fcl::HFNode <BV >::operator!=))
    return (boost::python::arg("self"), boost::python::arg("other"));
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &) const>(&hpp::fcl::HFNode <BV >::overlap))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

template <typename BV>
inline const char* member_func_doc (bool (hpp::fcl::HFNode <BV >::*function_ptr) (const hpp::fcl::HFNode <BV >  &, const hpp::fcl::CollisionRequest &,  hpp::fcl::FCL_REAL &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &, const hpp::fcl::CollisionRequest &,  hpp::fcl::FCL_REAL &) const>(&hpp::fcl::HFNode <BV >::overlap))
    return "Check whether two hpp::fcl::BVNode collide. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<4> member_func_args (bool (hpp::fcl::HFNode <BV >::*function_ptr) (const hpp::fcl::HFNode <BV >  &, const hpp::fcl::CollisionRequest &,  hpp::fcl::FCL_REAL &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &, const hpp::fcl::CollisionRequest &,  hpp::fcl::FCL_REAL &) const>(&hpp::fcl::HFNode <BV >::overlap))
    return (boost::python::arg("self"), boost::python::arg("other"), boost::python::arg("request"), boost::python::arg("sqrDistLowerBound"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"), boost::python::arg("arg2"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::FCL_REAL (hpp::fcl::HFNode <BV >::*function_ptr) (const hpp::fcl::HFNode <BV >  &,  hpp::fcl::Vec3f *,  hpp::fcl::Vec3f *) const)
{
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &,  hpp::fcl::Vec3f *,  hpp::fcl::Vec3f *) const>(&hpp::fcl::HFNode <BV >::distance))
    return "Compute the distance between two hpp::fcl::BVNode. P1 and P2, if not NULL and the underlying BV supports distance, return the nearest points. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<4> member_func_args ( hpp::fcl::FCL_REAL (hpp::fcl::HFNode <BV >::*function_ptr) (const hpp::fcl::HFNode <BV >  &,  hpp::fcl::Vec3f *,  hpp::fcl::Vec3f *) const)
{
  if (function_ptr == static_cast< hpp::fcl::FCL_REAL (hpp::fcl::HFNode <BV >::*) (const hpp::fcl::HFNode <BV >  &,  hpp::fcl::Vec3f *,  hpp::fcl::Vec3f *) const>(&hpp::fcl::HFNode <BV >::distance))
    return (boost::python::arg("self"), boost::python::arg("other"), boost::python::arg("P1"), boost::python::arg("P2"));
  return (boost::python::arg("self"), boost::python::arg("arg0"), boost::python::arg("arg1"), boost::python::arg("arg2"));
}

template <typename BV>
inline const char* member_func_doc ( hpp::fcl::Vec3f (hpp::fcl::HFNode <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::Vec3f (hpp::fcl::HFNode <BV >::*) () const>(&hpp::fcl::HFNode <BV >::getCenter))
    return "Access to the center of the BV. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args ( hpp::fcl::Vec3f (hpp::fcl::HFNode <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast< hpp::fcl::Vec3f (hpp::fcl::HFNode <BV >::*) () const>(&hpp::fcl::HFNode <BV >::getCenter))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

template <typename BV>
inline const char* member_func_doc (const hpp::fcl::Matrix3f & (hpp::fcl::HFNode <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<const hpp::fcl::Matrix3f & (hpp::fcl::HFNode <BV >::*) () const>(&hpp::fcl::HFNode <BV >::getOrientation))
    return "Access to the orientation of the BV. ";
  return "";
}

template <typename BV>
inline boost::python::detail::keywords<1> member_func_args (const hpp::fcl::Matrix3f & (hpp::fcl::HFNode <BV >::*function_ptr) () const)
{
  if (function_ptr == static_cast<const hpp::fcl::Matrix3f & (hpp::fcl::HFNode <BV >::*) () const>(&hpp::fcl::HFNode <BV >::getOrientation))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}
} // namespace doxygen
#include <hpp/fcl/hfield.h>

namespace doxygen {

template <>
struct class_doc_impl< hpp::fcl::HFNodeBase >
{
static inline const char* run ()
{
  return "";
}
static inline const char* attribute (const char* attrib)
{
  if (strcmp(attrib, "first_child") == 0)
    return "An index for first child node or primitive If the value is positive, it is the index of the first child bv node If the value is negative, it is -(primitive index + 1) Zero is not used. ";
  (void)attrib; // turn off unused parameter warning.
  return "";
}
};

template <>
struct constructor_0_impl< hpp::fcl::HFNodeBase >
{
static inline const char* doc ()
{
  return "Default constructor. ";
}
static inline boost::python::detail::keywords<0+1> args ()
{
  return (boost::python::arg("self"));
}
};

inline const char* member_func_doc (bool (hpp::fcl::HFNodeBase::*function_ptr) (const hpp::fcl::HFNodeBase &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNodeBase::*) (const hpp::fcl::HFNodeBase &) const>(&hpp::fcl::HFNodeBase::operator==))
    return "Comparison operator. ";
  if (function_ptr == static_cast<bool (hpp::fcl::HFNodeBase::*) (const hpp::fcl::HFNodeBase &) const>(&hpp::fcl::HFNodeBase::operator!=))
    return "Difference operator. ";
  return "";
}

inline boost::python::detail::keywords<2> member_func_args (bool (hpp::fcl::HFNodeBase::*function_ptr) (const hpp::fcl::HFNodeBase &) const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNodeBase::*) (const hpp::fcl::HFNodeBase &) const>(&hpp::fcl::HFNodeBase::operator==))
    return (boost::python::arg("self"), boost::python::arg("other"));
  if (function_ptr == static_cast<bool (hpp::fcl::HFNodeBase::*) (const hpp::fcl::HFNodeBase &) const>(&hpp::fcl::HFNodeBase::operator!=))
    return (boost::python::arg("self"), boost::python::arg("other"));
  return (boost::python::arg("self"), boost::python::arg("arg0"));
}

inline const char* member_func_doc (bool (hpp::fcl::HFNodeBase::*function_ptr) () const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::isLeaf))
    return "Whether current node is a leaf node (i.e. contains a primitive index) ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (bool (hpp::fcl::HFNodeBase::*function_ptr) () const)
{
  if (function_ptr == static_cast<bool (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::isLeaf))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (size_t (hpp::fcl::HFNodeBase::*function_ptr) () const)
{
  if (function_ptr == static_cast<size_t (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::leftChild))
    return "Return the index of the first child. The index is referred to the bounding volume array (i.e. bvs) in hpp::fcl::BVHModel. ";
  if (function_ptr == static_cast<size_t (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::rightChild))
    return "Return the index of the second child. The index is referred to the bounding volume array (i.e. bvs) in hpp::fcl::BVHModel. ";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (size_t (hpp::fcl::HFNodeBase::*function_ptr) () const)
{
  if (function_ptr == static_cast<size_t (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::leftChild))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<size_t (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::rightChild))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}

inline const char* member_func_doc (Eigen::Vector2i (hpp::fcl::HFNodeBase::*function_ptr) () const)
{
  if (function_ptr == static_cast<Eigen::Vector2i (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::leftChildIndexes))
    return "";
  if (function_ptr == static_cast<Eigen::Vector2i (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::rightChildIndexes))
    return "";
  return "";
}

inline boost::python::detail::keywords<1> member_func_args (Eigen::Vector2i (hpp::fcl::HFNodeBase::*function_ptr) () const)
{
  if (function_ptr == static_cast<Eigen::Vector2i (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::leftChildIndexes))
    return (boost::python::arg("self"));
  if (function_ptr == static_cast<Eigen::Vector2i (hpp::fcl::HFNodeBase::*) () const>(&hpp::fcl::HFNodeBase::rightChildIndexes))
    return (boost::python::arg("self"));
  return (boost::python::arg("self"));
}
} // namespace doxygen
#include <hpp/fcl/hfield.h>

namespace doxygen {
} // namespace doxygen

#endif // DOXYGEN_AUTODOC_HPP_FCL_HFIELD_H

